<?php

namespace Teknisa\CADFIS\Factories;

use Doctrine\ORM\EntityManager; 

class Ger05500ProdutosDesoneracaoImpostosFactory {
    protected $entityManager;
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection    = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    public function verificaFornecedor($CDPRODUTO, $NRORG){
        try {
         
            $sql = "SELECT P.CDPRODUTO,
                              P.CDFORNECED,
                              P.NRORG,
                              P.DTINCLUSAO,
                              P.DTULTATU,
                              P.NRORGINCLUSAO,
                              P.CDOPERINCLUSAO,
                              P.NRORGULTATU,
                              P.CDOPERULTATU,
                              P.IDATIVO,
                              F.NMRAZSOCFORN,
                              F.NRINSJURFORN
                            FROM PRODESONERAIMFOR P
                            JOIN FORNECEDOR F
                            ON F.NRORG       = P.NRORG
                            AND F.CDFORNECED = P.CDFORNECED
                            WHERE P.CDPRODUTO = :CDPRODUTO AND
                            P.NRORG = :NRORG";

            $params = array(
                "CDPRODUTO"=>$CDPRODUTO,
                "NRORG"=>$NRORG
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }
    
    public function deleteFornecedor($CDPRODUTO, $NRORG){
        try {
         
            $sql = "DELETE FROM PRODESONERAIMFOR
                        WHERE CDPRODUTO = :CDPRODUTO AND
                        NRORG = :NRORG";

            $params = array(
                "CDPRODUTO"=>$CDPRODUTO,
                "NRORG"=>$NRORG
            );
            
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }
    
    public function verificaCliente($CDPRODUTO, $NRORG){
        try {
         
            $sql = "SELECT P.CDPRODUTO,
                        P.CDCLIENTE,
                        P.NRORG,
                        P.DTINCLUSAO,
                        P.DTULTATU,
                        P.NRORGINCLUSAO,
                        P.CDOPERINCLUSAO,
                        P.NRORGULTATU,
                        P.CDOPERULTATU,
                        P.IDATIVO,
                        C.NMRAZSOCCLIE,
                        C.NRINSJURCLIE
                            FROM PRODESONERAIMCLI P
                            JOIN CLIENTE C
                            ON C.NRORG      = P.NRORG
                            AND C.CDCLIENTE = P.CDCLIENTE
                            WHERE P.CDPRODUTO = :CDPRODUTO AND
                            P.NRORG = :NRORG";

            $params = array(
                "CDPRODUTO"=>$CDPRODUTO,
                "NRORG"=>$NRORG
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }
    
    public function deleteCliente($CDPRODUTO, $NRORG){
        try {
         
            $sql = "DELETE FROM PRODESONERAIMCLI
                        WHERE CDPRODUTO = :CDPRODUTO AND
                        NRORG = :NRORG";

            $params = array(
                "CDPRODUTO"=>$CDPRODUTO,
                "NRORG"=>$NRORG
            );
            
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }
    
    public function verificaFilial($CDPRODUTO, $NRORG){
        try {
         
            $sql = "SELECT P.CDPRODUTO,
                        P.CDFILIAL,
                        P.NRORG,
                        P.DTINCLUSAO,
                        P.DTULTATU,
                        P.NRORGINCLUSAO,
                        P.CDOPERINCLUSAO,
                        P.NRORGULTATU,
                        P.CDOPERULTATU,
                        P.IDATIVO,
                        F.NMFILIAL
                            FROM PRODESONERAIMFIL P
                            JOIN FILIAL F
                            ON F.NRORG     = P.NRORG
                            AND F.CDFILIAL = P.CDFILIAL
                            WHERE P.CDPRODUTO = :CDPRODUTO AND
                            P.NRORG = :NRORG";

            $params = array(
                "CDPRODUTO"=>$CDPRODUTO,
                "NRORG"=>$NRORG
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }

    public function deleteFilial($CDPRODUTO, $NRORG){
        try {
         
            $sql = "DELETE FROM PRODESONERAIMFIL
                        WHERE CDPRODUTO = :CDPRODUTO AND
                        NRORG = :NRORG";

            $params = array(
                "CDPRODUTO"=>$CDPRODUTO,
                "NRORG"=>$NRORG
            );
            
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }
    
}